@@ -2,12 +2,11 @@ use std::net::SocketAddr;
 use std::sync::Arc;
 
 use super::{hash, random_msg};
-use crate::{api::bind, config::SerialisableCertificate, peer_config};
-use anyhow::Result;
+use crate::config::InternalConfig;
 use bytes::Bytes;
+use color_eyre::eyre::{eyre, Report, Result};
 use futures::stream::FuturesUnordered;
 use futures::StreamExt;
-use peer_config::{DEFAULT_IDLE_TIMEOUT_MSEC, DEFAULT_KEEP_ALIVE_INTERVAL_MSEC};
 use std::collections::BTreeSet;
 use tokio::sync::{
     mpsc::{channel, unbounded_channel, Receiver, Sender, UnboundedReceiver, UnboundedSender},
@@ -63,24 +62,12 @@ struct Peer {
 impl Peer {
     // Takes the channel size. Set `0` to use an unbounded channel.
     fn new(channel_size: usize) -> Result<(Self, ChannelReceiver<(SocketAddr, Bytes)>)> {
-        let (key, cert) = {
-            let our_complete_cert = SerialisableCertificate::new(vec![DOMAIN.to_string()])?;
-            our_complete_cert.obtain_priv_key_and_cert()?
-        };
+        let config = InternalConfig::try_from_config(Default::default())?;
 
-        let endpoint_cfg = peer_config::new_our_cfg(
-            DEFAULT_IDLE_TIMEOUT_MSEC,
-            DEFAULT_KEEP_ALIVE_INTERVAL_MSEC,
-            cert,
-            key,
-        )?;
+        let mut builder = quinn::Endpoint::builder();
+        let _ = builder.listen(config.server.clone());
 
-        let client_cfg = peer_config::new_client_cfg(
-            DEFAULT_IDLE_TIMEOUT_MSEC,
-            DEFAULT_KEEP_ALIVE_INTERVAL_MSEC,
-        )?;
-
-        let (endpoint, mut incoming) = bind(endpoint_cfg, "127.0.0.1:0".parse()?, true)?;
+        let (endpoint, mut incoming) = builder.bind(&"127.0.0.1:0".parse()?)?;
 
         let (message_tx, message_rx) = if channel_size == 0 {
             let (message_tx, message_rx) = unbounded_channel();
@@ -130,7 +117,7 @@ impl Peer {
         Ok((
             Peer {
                 endpoint,
-                client_cfg,
+                client_cfg: config.client,
                 message_tx,
                 connections,
             },
@@ -167,7 +154,7 @@ fn listen_for_messages(
     let _ = tokio::spawn(async move {
         read_from_stream(&mut uni_streams, src, message_tx).await?;
         trace!("The connection to {:?} has been terminated.", src);
-        Ok::<(), anyhow::Error>(())
+        Ok::<(), Report>(())
     });
 }
 
@@ -229,9 +216,9 @@ async fn multiple_connections_with_many_concurrent_messages() -> Result<()> {
                 sending_endpoint
                     .send_message(&src, hash_result.to_vec().into())
                     .await
-                    .map_err(|err| anyhow::anyhow!("Error here: {:?}", err))?;
+                    .map_err(|err| eyre!("Error here: {:?}", err))?;
 
-                Ok::<_, anyhow::Error>(())
+                Ok::<_, Report>(())
             });
 
             num_received += 1;
@@ -241,7 +228,7 @@ async fn multiple_connections_with_many_concurrent_messages() -> Result<()> {
             }
         }
 
-        Ok::<_, anyhow::Error>(())
+        Ok::<_, Report>(())
     });
 
     let mut senders = Vec::new();
@@ -273,7 +260,7 @@ async fn multiple_connections_with_many_concurrent_messages() -> Result<()> {
             info!("Sender #{} recv complete", id);
             send_complete_rx.notified().await;
             sender.close();
-            Ok::<_, anyhow::Error>(())
+            Ok::<_, Report>(())
         }));
 
         let hashes = hash_results.clone();
@@ -286,12 +273,12 @@ async fn multiple_connections_with_many_concurrent_messages() -> Result<()> {
                 sender
                     .send_message(&server_addr, message.clone())
                     .await
-                    .map_err(|err| anyhow::anyhow!("Error now here: {:?}", err))?;
+                    .map_err(|err| eyre!("Error now here: {:?}", err))?;
             }
             info!("Sender #{} send complete", id);
             send_complete.notify_one();
 
-            Ok::<_, anyhow::Error>(())
+            Ok::<_, Report>(())
         }));
     }
     tasks.push(server_handle);
